==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/0f/0f3ea52f20cf0e54646b4e14776a3221.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PageBundle/Event/UntrackableUrlsEvent.php */
class __TwigTemplate_90b8d2877d3e450279840b1aa8cc82db extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\PageBundle\\Event;

use Symfony\\Contracts\\EventDispatcher\\Event;

class UntrackableUrlsEvent extends Event
{
    /**
     * @var string[]
     */
    private array \$doNotTrack = [
        '{webview_url}',
        '{resubscribe_url}',
        '{unsubscribe_url}',
        '{dnc_url}',
        '{trackable=(.*?)}',
    ];

    /**
     * @param mixed \$content
     */
    public function __construct(
        private \$content
    ) {
    }

    /**
     * set a URL or token to not convert to trackables.
     */
    public function addNonTrackable(\$url): void
    {
        \$this->doNotTrack[] = \$url;
    }

    /**
     * Get array of non-trackables.
     *
     * @return string[]
     */
    public function getDoNotTrackList(): array
    {
        return \$this->doNotTrack;
    }

    /**
     * @return string
     */
    public function getContent()
    {
        return \$this->content;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PageBundle/Event/UntrackableUrlsEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PageBundle/Event/UntrackableUrlsEvent.php", "/var/www/mautic-ktn/app/bundles/PageBundle/Event/UntrackableUrlsEvent.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/0f/0f3ea52f20cf0e54646b4e14776a3221.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PageBundle/Event/UntrackableUrlsEvent.php */
class __TwigTemplate_90b8d2877d3e450279840b1aa8cc82db extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\PageBundle\\Event;

use Symfony\\Contracts\\EventDispatcher\\Event;

class UntrackableUrlsEvent extends Event
{
    /**
     * @var string[]
     */
    private array \$doNotTrack = [
        '{webview_url}',
        '{resubscribe_url}',
        '{unsubscribe_url}',
        '{dnc_url}',
        '{trackable=(.*?)}',
    ];

    /**
     * @param mixed \$content
     */
    public function __construct(
        private \$content
    ) {
    }

    /**
     * set a URL or token to not convert to trackables.
     */
    public function addNonTrackable(\$url): void
    {
        \$this->doNotTrack[] = \$url;
    }

    /**
     * Get array of non-trackables.
     *
     * @return string[]
     */
    public function getDoNotTrackList(): array
    {
        return \$this->doNotTrack;
    }

    /**
     * @return string
     */
    public function getContent()
    {
        return \$this->content;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PageBundle/Event/UntrackableUrlsEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PageBundle/Event/UntrackableUrlsEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/PageBundle/Event/UntrackableUrlsEvent.php");
    }
}
